@@ -36,8 +36,6 @@ struct {
 
 static integer c__2 = 2;
 static integer c__1 = 1;
-static integer c__9 = 9;
-static integer c__5 = 5;
 
 /* Subroutine */ int stoda_(integer *neq, doublereal *y, doublereal *yh, 
 	integer *nyh, doublereal *yh1, doublereal *ewt, doublereal *savf, 
@@ -55,15 +53,13 @@ static integer c__5 = 5;
     doublereal d__1, d__2, d__3;
 
     /* Builtin functions */
-    integer s_wsle(cilist *), do_lio(integer *, integer *, char *, ftnlen), 
-	    e_wsle(void);
     double pow_dd(doublereal *, doublereal *);
 
     /* Local variables */
     static integer i__, j, m;
     static doublereal r__;
     static integer i1, jb;
-    static doublereal rh, rm, econ_value__, dm1, dm2;
+    static doublereal rh, rm, dm1, dm2;
     static integer lm1, lm2;
     static doublereal rh1, rh2, del, ddn;
     static integer ncf;
@@ -88,10 +84,6 @@ static integer c__5 = 5;
     static real el0save;
     static doublereal lastel0;
 
-    /* Fortran I/O blocks */
-    static cilist io___27 = { 0, 6, 0, 0, 0 };
-
-
 /* lll. optimize */
     /* Parameter adjustments */
     --neq;
@@ -457,11 +449,6 @@ L270:
 /* p as coefficient matrix. */
 /* ----------------------------------------------------------------------- */
 L350:
-/*     write(*, 351), 'h = ', h */
-/*     write(*, 351), 'savf = ', savf(1) */
-/*     write(*, 351), 'yhi2 = ', yh(1, 2) */
-/*     write(*, 351), 'acor = ', acor(1) */
-/* 351  format(A10, e20.13) */
     i__2 = ls0001_1.n;
     for (i__ = 1; i__ <= i__2; ++i__) {
 /* L360: */
@@ -481,9 +468,6 @@ L350:
     (*lu_solver__)(&ls0001_1.tn, &y[1], &lasty[1], &ier);
     ls0001_1.h__ = hsave;
     ls0001_1.el0 = el0save;
-/*     write (6, 364), y(1), y(2), y(3) */
-/* 364  format('solver: sol = ', 3e13.6) */
-/*     call slvs (wm, iwm, y, savf) */
     if (ls0001_1.iersl < 0) {
 	goto L430;
     }
@@ -510,8 +494,6 @@ L350:
 /* estimate.  pdlast is the most recent nonzero estimate. */
 /* ----------------------------------------------------------------------- */
 L400:
-/*     call econ (neq, tn, y, econ_value) */
-/*     if (dabs(econ_value) .gt. 1e-5) go to 408 */
     if (del <= pnorm * 100. * ls0001_1.uround) {
 	goto L450;
     }
@@ -555,7 +537,6 @@ L405:
     }
     delp = del;
     srcma_(rsav, isav, &c__1);
-/*     write(*, *), "call f 340" */
     (*f)(&neq[1], &ls0001_1.tn, &y[1], &savf[1]);
 /*     SCIPY error check: */
     if (neq[1] == -1) {
@@ -564,15 +545,6 @@ L405:
     srcma_(rsav, isav, &c__2);
     ++ls0001_1.nfe;
     goto L270;
-/* L408: */
-    s_wsle(&io___27);
-    do_lio(&c__9, &c__1, "econ crit failed at t=", (ftnlen)22);
-    do_lio(&c__5, &c__1, (char *)&ls0001_1.tn, (ftnlen)sizeof(doublereal));
-    do_lio(&c__9, &c__1, "for h=", (ftnlen)6);
-    do_lio(&c__5, &c__1, (char *)&ls0001_1.h__, (ftnlen)sizeof(doublereal));
-    do_lio(&c__9, &c__1, "econ is", (ftnlen)7);
-    do_lio(&c__5, &c__1, (char *)&econ_value__, (ftnlen)sizeof(doublereal));
-    e_wsle();
 /* ----------------------------------------------------------------------- */
 /* the corrector iteration failed to converge. */
 /* if miter .ne. 0 and the jacobian is out of date, pjac is called for */
