@@ -302,11 +302,6 @@ c p as coefficient matrix.
 c-----------------------------------------------------------------------
 
  350  continue
-c     write(*, 351), 'h = ', h
-c     write(*, 351), 'savf = ', savf(1)
-c     write(*, 351), 'yhi2 = ', yh(1, 2)
-c     write(*, 351), 'acor = ', acor(1)
-c351  format(A10, e20.13)
       do 360 i = 1,n
  360    y(i) = h*savf(i) - (yh(i,2) + acor(i))
 
@@ -324,9 +319,6 @@ c     this is new:
       call lu_solver(tn, y, lasty, ier)
       h = hsave
       el0 = el0save
-c     write (6, 364), y(1), y(2), y(3)
-c364  format('solver: sol = ', 3e13.6)
-c     call slvs (wm, iwm, y, savf)
       if (iersl .lt. 0) go to 430
       if (iersl .gt. 0) go to 410
       del = vmnorm (n, y, ewt)
@@ -346,8 +338,6 @@ c on convergence, form pdest = local maximum lipschitz constant
 c estimate.  pdlast is the most recent nonzero estimate.
 c-----------------------------------------------------------------------
  400  continue
-c     call econ (neq, tn, y, econ_value)
-c     if (dabs(econ_value) .gt. 1e-5) go to 408
       if (del .le. 100.0d0*pnorm*uround) go to 450
       if (m .eq. 0 .and. meth .eq. 1) go to 405
       if (m .eq. 0) go to 402
@@ -366,7 +356,6 @@ c     if (dabs(econ_value) .gt. 1e-5) go to 408
       if (m .ge. 2 .and. del .gt. 2.0d0*delp) go to 410
       delp = del
       call srcma (rsav, isav, 1)
-c     write(*, *), "call f 340"
       call f (neq, tn, y, savf)
 c     SCIPY error check:
       if (neq(1) .eq. -1) return
@@ -374,8 +363,6 @@ c     SCIPY error check:
       nfe = nfe + 1
       go to 270
 
- 408  write(*, *), 'econ crit failed at t=', tn, 'for h=', h, 'econ is',
-     1             econ_value
 c-----------------------------------------------------------------------
 c the corrector iteration failed to converge.
 c if miter .ne. 0 and the jacobian is out of date, pjac is called for
