@@ -75,7 +75,8 @@ class Cache:
         create_folder_if_not_exists(folder)
         self._path = os.path.join(folder, unique_id_ode)
         if os.path.exists(self._path):
-            self._cache = pickle.load(open(self._path, "rb"))
+            with open(self._path, "rb") as fh:
+                self._cache = pickle.load(fh)
         else:
             self._cache = {}
 
@@ -129,7 +130,7 @@ def setup_code_generation(
         M.rows,
         "non zeros:",
         count_nz,
-        "sparsity: %.3f %%" % (100 * count_nz / M.rows ** 2),
+        "sparsity: %.3f %%" % (100 * count_nz / M.rows**2),
     )
     return cache, J, h, el0, M, rhs
 
@@ -373,12 +374,14 @@ def generate_solve_split(id_, all_traces, splits, N):
 
     for level, traces in all_traces.items():
         yield f"    int solver_{level} = _next_solver_{id_}[{level}];"
-        yield f"    _call_counts_{id_}.at({level}).at(solver_{level})++;"
 
     yield ""
     yield f"    int _tried_0[{n_traces}] = {{ 0 }};"
     yield f"    if (__enable_fast_solver_{id_} == 0) solver_0 = {n_traces};"
 
+    for level, traces in all_traces.items():
+        yield f"    _call_counts_{id_}.at({level}).at(solver_{level})++;"
+
     for j in range(len(all_traces[0])):
         yield f"    if (solver_0 == {j})"
         yield (
@@ -454,7 +457,6 @@ def _create_split_lu_0(
         " int _consider_sparsity) {"
     )
 
-    yield f"    // {R}"
     yield ""
     yield from init_state_vars_from_y(state_vars, indent="    ")
     yield from create_xi_varables(sub_assignments, expression_to_c)
@@ -506,7 +508,6 @@ def _create_split_lu_i(
         f"double *__restrict__ _x, double *__restrict__ _y, int * _tried,"
         " int _consider_sparsity) {"
     )
-    yield f"    // {traces[trace_idx]}"
     yield ""
     yield from init_state_vars_from_y(state_vars, indent="    ")
     yield from create_xi_varables(sub_assignments, expression_to_c)
@@ -1193,8 +1194,8 @@ def main():
     rhs = Matrix(
         [
             -0.04 * y0 + 1e4 * y1 * y2,
-            0.04 * y0 - 1e4 * y1 * y2 - 3e7 * y1 ** 2,
-            3e7 * y1 ** 2,
+            0.04 * y0 - 1e4 * y1 * y2 - 3e7 * y1**2,
+            3e7 * y1**2,
         ]
     )
 
