@@ -213,7 +213,8 @@ class Module(object):
 
     @staticmethod
     def parse_sympy_file(path, locals_=None):
-        return Module.parse_sympy_code(open(path, "r").read(), locals_)
+        with open(path, "r") as fh:
+            return Module.parse_sympy_code(fh.read(), locals_)
 
     def get_module_wrapper(self):
         return ModuleWrapper(self)
@@ -546,6 +547,7 @@ def _general_cython_code(unique_id):
            |
            |cimport libc.stdio as stdio
            |from libc.stdio cimport printf
+           |from libc.stdlib cimport malloc
            |from posix.time cimport timeval, gettimeofday
            |from libcpp.vector cimport vector
            |from libcpp.set cimport set as cset
@@ -559,6 +561,9 @@ def _general_cython_code(unique_id):
            |
            |cimport numpy as np
            |import numpy as np
+           |import ctypes
+           |
+           |_api = {{}}
            |
            |cdef long microtime():
            |     cdef timeval time
@@ -569,6 +574,7 @@ def _general_cython_code(unique_id):
            |
            |def get_unique_id():
            |    return "{unique_id}"
+           |
            """.format(
             unique_id=unique_id, version=__version__
         )
@@ -592,8 +598,6 @@ def _gsl_related_header():
     |
     |using namespace std;
     |
-    |typedef void (*error_callback_t)(string, double, double);
-    |
     |enum QuadPackMethod {
     |    QNG,
     |    QAG,
@@ -606,9 +610,11 @@ def _gsl_related_header():
     |extern "C" void clear_last_warning_message();
     |extern "C" void set_eps_rel(string id, double value);
     |extern "C" void set_eps_abs(string id, double value);
+    |extern "C" double get_rel_err(string id);
+    |extern "C" double get_abs_err(string id);
+    |extern "C" void set_eps_abs(string id, double value);
     |extern "C" void set_max_intervals(string id, size_t value);
     |extern "C" void set_quadpack_method(string id, QuadPackMethod m);
-    |extern "C" void set_error_callback(error_callback_t cb);
     |extern "C" void set_gsl_error_handler();
     |
     """
@@ -653,22 +659,35 @@ def _gsl_related_c_code():
         |static unordered_map<string, size_t> id_to_max_intervals = {{"default", 1000}};
         |static unordered_map<string, QuadPackMethod> id_to_quadpack_method
         |                                             = {{"default", QAG}};
-        |static error_callback_t error_callback = 0;
         |
+        |static unordered_map<string, double> id_to_rel_err = {{ }};
+        |static unordered_map<string, double> id_to_abs_err = {{ }};
+
         |extern "C" {
         |    const char * get_last_error_message() { return last_error_message; }
         |    const char * get_last_warning_message() { return last_warning_message; }
         |    void clear_last_error_message() { last_error_message[0] = 0; }
         |    void clear_last_warning_message() { last_warning_message[0] = 0; }
+        |
         |    void set_eps_rel(string id, double value) { id_to_eps_rel[id] = value; }
         |    void set_eps_abs(string id, double value) { id_to_eps_abs[id] = value; }
+        |
+        |    void set_rel_err(string id, double value) { id_to_rel_err[id] = value; }
+        |    void set_abs_err(string id, double value) { id_to_abs_err[id] = value; }
+        |
+        |    double get_rel_err(string id) {
+        |        return id_to_rel_err.count(id) > 0 ? id_to_rel_err[id]: -1.0;
+        |    }
+        |    double get_abs_err(string id) {
+        |        return id_to_abs_err.count(id) > 0 ? id_to_abs_err[id]: -1.0;
+        |    }
+        |
         |    void set_max_intervals(string id, size_t value) {
         |        id_to_max_intervals[id] = value;
         |    }
         |    void set_quadpack_method(string id, QuadPackMethod m) {
         |         id_to_quadpack_method[id] = m;
         |    }
-        |    void set_error_callback(error_callback_t cb) { error_callback = cb; }
         |}
         |
         |void handler (const char * reason, const char * file, int line, int gsl_errno)
@@ -781,10 +800,15 @@ def _gsl_related_c_code():
         |                                       max_intervals, GSL_INTEG_GAUSS31, w,
         |                                       &result, &error);
         |
-        |        if (err_code)
+        |        if (err_code) {
         |            set_error_message_gsl("qag from gsl returned", err_code);
-        |        else if (error_callback)
-        |            error_callback(id, error, error / result);
+        |            set_abs_err(id, -1.0);
+        |            set_rel_err(id, -1.0);
+        |            }
+        |        else {
+        |            set_abs_err(id, error);
+        |            set_rel_err(id, error / result);
+        |        }
         |        gsl_integration_workspace_free(w);
         |
         |    } else if (method == QAGI) {
@@ -830,8 +854,15 @@ def _gsl_related_c_code():
         |        }
         |        result *= sign;
         |
-        |        if (!err_code && error_callback)
-        |            error_callback(id, error, error / result);
+        |        if (err_code) {
+        |            set_error_message_gsl("qagi from gsl returned", err_code);
+        |            set_abs_err(id, -1.0);
+        |            set_rel_err(id, -1.0);
+        |            }
+        |        else {
+        |            set_abs_err(id, error);
+        |            set_rel_err(id, error / result);
+        |        }
         |
         |        gsl_integration_workspace_free(w);
         |
@@ -840,14 +871,93 @@ def _gsl_related_c_code():
         |        size_t neval;
         |        err_code = gsl_integration_qng(&F, low, high, eps_abs, eps_rel,
         |                                       &result, &error, &neval);
-        |        if (err_code)
-        |            set_error_message_gsl("qng from gsl returned", err_code);
-        |        else if (error_callback)
-        |            error_callback(id, error, error / result);
+        |
+        |        if (err_code) {
+        |            set_error_message_gsl("qagi from gsl returned", err_code);
+        |            set_abs_err(id, -1.0);
+        |            set_rel_err(id, -1.0);
+        |            }
+        |        else {
+        |            set_abs_err(id, error);
+        |            set_rel_err(id, error / result);
+        |        }
         |    }
         |
         |    return result;
         |}
+        |
+        |typedef struct
+        |   {
+        |   double * c;
+        |   double * g;
+        |   double * diag;
+        |   double * offdiag;
+        |} cspline_state_t;
+        |
+        |static inline void
+        |coeff_calc (const double c_array[], double dy, double dx, size_t index,
+        |            double * b, double * c, double * d)
+        |{
+        |    const double c_i = c_array[index];
+        |    const double c_ip1 = c_array[index + 1];
+        |    *b = (dy / dx) - dx * (c_ip1 + 2.0 * c_i) / 3.0;
+        |    *c = c_i;
+        |    *d = (c_ip1 - c_i) / (3.0 * dx);
+        |}
+        |
+        |static
+        |void
+        |cspline_eval_vector_sorted (const void * vstate,
+        |            const double x_array[], const double y_array[], size_t size,
+        |            double *x, int n,
+        |            double *y)
+        |{
+        |    const cspline_state_t *state = (const cspline_state_t *) vstate;
+        |
+        |    double x_lo, x_hi;
+        |    double dx;
+        |    double xi;
+        |    size_t index = 0;
+        |
+        |    index = gsl_interp_bsearch (x_array, x[0], 0, size - 1);
+        |
+        |    for (size_t ii=0; ii < n; ++ii) {
+        |        xi = x[ii];
+        |        y[ii] = NAN;
+        |
+        |        if (xi < x_array[0]) continue;
+        |        if (xi > x_array[size - 1]) continue;
+        |        while ((xi < x_array[index] || xi >= x_array[index + 1])
+        |               && index < size - 2)
+        |                   index ++;
+        |       if (index < size - 2)
+        |           if (xi < x_array[index] || xi >= x_array[index + 1]) {
+        |              // printf("no match %d %lf %lf %lf\\n", index, xi, x_array[index], x_array[index + 1]);
+        |              continue;
+        |        }
+        |
+        |        if (index == size - 2)
+        |           if (xi < x_array[index] || xi > x_array[index + 1]) {
+        |              // printf("no match %d %lf %lf %lf\\n", index, xi, x_array[index], x_array[index + 1]);
+        |              continue;
+        |        }
+        |
+        |        /* evaluate */
+        |        x_hi = x_array[index + 1];
+        |        x_lo = x_array[index];
+        |        dx = x_hi - x_lo;
+        |        if (dx > 0.0) {
+        |            const double y_lo = y_array[index];
+        |            const double y_hi = y_array[index + 1];
+        |            const double dy = y_hi - y_lo;
+        |            double delx = xi - x_lo;
+        |            double b_i, c_i, d_i;
+        |            coeff_calc(state->c, dy, dx, index,  &b_i, &c_i, &d_i);
+        |            // printf("%d %lf %lf %lf %lf %lf\\n", index, dy, dx, b_i, c_i, d_i);
+        |            y[ii] = y_lo + delx * (b_i + delx * (c_i + delx * d_i));
+        |        }
+        |    }
+        |}
         """
     )
 
@@ -864,19 +974,29 @@ def _gsl_related_cython_code(header_file_path):
            |        QAGI
            |
            |cdef extern from "{header_file_path}":
-           |    ctypedef void (*error_callback_t)(string, double, double)
            |
-           |    char * get_last_error_message()
-           |    char * get_last_warning_message()
+           |    char * c_get_last_error_message "get_last_error_message"()
+           |    char * c_get_last_warning_message "get_last_warning_message"()
            |    void clear_last_error_message()
            |    void clear_last_warning_message()
            |    void set_gsl_error_handler()
            |    void c_set_eps_rel "set_eps_rel"(string, double)
-           |    void c_set_eps_rel "set_eps_rel"(string, double)
            |    void c_set_eps_abs "set_eps_abs"(string, double)
+           |
+           |    void c_set_rel_err "set_rel_err"(string, double)
+           |    void c_set_abs_err "set_abs_err"(string, double)
+           |    double c_get_rel_err "get_rel_err"(string)
+           |    double c_get_abs_err "get_abs_err"(string)
+           |
            |    void c_set_max_intervals "set_max_intervals"(string, size_t)
            |    void c_set_quadpack_method "set_quadpack_method"(string, QuadPackMethod)
-           |    void c_set_error_callback "set_error_callback"(error_callback_t)
+           |
+           |def get_last_error_message():
+           |    return str(c_get_last_error_message(), "utf-8")
+           |
+           |def get_last_warning_message():
+           |    return str(c_get_last_warning_message(), "utf-8")
+           |
         """.format(
             header_file_path=header_file_path
         )
@@ -903,19 +1023,12 @@ def _gsl_related_cython_code(header_file_path):
         |    else:
         |       raise ValueError("unknown quadpack method {}".format(value))
         |
-        |cdef dict call_back_map = {}
         |set_gsl_error_handler()
         |
-        |cdef void c_callback(string id, double abs_err, double rel_err):
-        |    cdef str py_id = str(id, "ascii")
-        |    global call_back_map
-        |    if py_id in call_back_map:
-        |        call_back_map[py_id](abs_err, rel_err)
-        |
-        |def set_error_callback(str id, object cb):
-        |    global call_back_map
-        |    c_set_error_callback(c_callback)
-        |    call_back_map[id] = cb
+        |def get_abs_err(str id):
+        |    return c_get_abs_err(id.encode("ascii"))
+        |def get_rel_err(str id):
+        |    return c_get_rel_err(id.encode("ascii"))
         """
     )
 
