@@ -33,10 +33,10 @@ def get_platform():
     os, *version, machine = platform.split("-")
     if os != "macosx":
         return platform
-    python_exe_path = subprocess.check_output(["which", "python"], text=True)
-    file_type = subprocess.check_output(["file", python_exe_path], text=True)
+    python_exe_path = subprocess.check_output(["which", "python"], text=True).strip()
+    file_type = subprocess.check_output(["file", python_exe_path], text=True).strip()
     machine = file_type.split(" ")[-1]
-    return "-".join([os, version, machine])
+    return "-".join([os, *version, machine])
 
 
 def create_folder_if_not_exists(folder):
